==> qtjambi-webenginewidgets-5.15.17-sources.jar: io/qt/webengine/widgets/QWebEngineHistory.java <==
package io.qt.webengine.widgets;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QWebEngineHistory</code></p>
 */
public final class QWebEngineHistory extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr>back()</code></p>
     */
    @QtUninvokable
    public final void back(){
        back_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void back_native(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr>backItem()const</code></p>
     */
    @QtUninvokable
    public final io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem backItem(){
        return backItem_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.webengine.widgets.QWebEngineHistoryItem backItem_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr>backItems(int)const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem> backItems(int maxItems){
        return backItems_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), maxItems);
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.widgets.QWebEngineHistoryItem> backItems_native_int_constfct(long __this__nativeId, int maxItems);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr>canGoBack()const</code></p>
     */
    @QtUninvokable
    public final boolean canGoBack(){
        return canGoBack_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean canGoBack_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr>canGoForward()const</code></p>
     */
    @QtUninvokable
    public final boolean canGoForward(){
        return canGoForward_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean canGoForward_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr>clear()</code></p>
     */
    @QtUninvokable
    public final void clear(){
        clear_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clear_native(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr>count()const</code></p>
     */
    @QtUninvokable
    public final int count(){
        return count_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int count_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr>currentItem()const</code></p>
     */
    @QtUninvokable
    public final io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem currentItem(){
        return currentItem_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.webengine.widgets.QWebEngineHistoryItem currentItem_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr>currentItemIndex()const</code></p>
     */
    @QtUninvokable
    public final int currentItemIndex(){
        return currentItemIndex_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int currentItemIndex_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr>forward()</code></p>
     */
    @QtUninvokable
    public final void forward(){
        forward_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void forward_native(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr>forwardItem()const</code></p>
     */
    @QtUninvokable
    public final io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem forwardItem(){
        return forwardItem_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.webengine.widgets.QWebEngineHistoryItem forwardItem_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr>forwardItems(int)const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem> forwardItems(int maxItems){
        return forwardItems_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), maxItems);
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.widgets.QWebEngineHistoryItem> forwardItems_native_int_constfct(long __this__nativeId, int maxItems);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr>goToItem(QWebEngineHistoryItem)</code></p>
     */
    @QtUninvokable
    public final void goToItem(io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem item){
        goToItem_native_cref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(item));
    }
    
    @QtUninvokable
    private native void goToItem_native_cref_QWebEngineHistoryItem(long __this__nativeId, long item);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr>itemAt(int)const</code></p>
     */
    @QtUninvokable
    public final io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem itemAt(int i){
        return itemAt_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), i);
    }
    
    @QtUninvokable
    private native io.qt.webengine.widgets.QWebEngineHistoryItem itemAt_native_int_constfct(long __this__nativeId, int i);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr>items()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem> items(){
        return items_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.widgets.QWebEngineHistoryItem> items_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>operator&lt;&lt;(QDataStream&amp;,<wbr>QWebEngineHistory)</code></p>
     */
    @QtUninvokable
    public void writeTo(io.qt.core.@StrictNonNull QDataStream stream){
        java.util.Objects.requireNonNull(stream, "Argument 'stream': null not expected.");
        writeTo_native_ref_QDataStream(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(stream));
    }
    
    @QtUninvokable
    private native void writeTo_native_ref_QDataStream(long __this__nativeId, long stream);
    
    /**
     * <p>See <code>operator&gt;&gt;(QDataStream&amp;,<wbr>QWebEngineHistory&amp;)</code></p>
     */
    @QtUninvokable
    public void readFrom(io.qt.core.@StrictNonNull QDataStream stream){
        java.util.Objects.requireNonNull(stream, "Argument 'stream': null not expected.");
        readFrom_native_ref_QDataStream(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(stream));
    }
    
    @QtUninvokable
    private native void readFrom_native_ref_QDataStream(long __this__nativeId, long stream);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineHistory(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-webenginewidgets-5.15.18-sources.jar: io/qt/webengine/widgets/QWebEngineHistory.java <==
package io.qt.webengine.widgets;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QWebEngineHistory</code></p>
 */
public final class QWebEngineHistory extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr/>back()</code></p>
     */
    @QtUninvokable
    public final void back(){
        back_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void back_native(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr/>backItem()const</code></p>
     */
    @QtUninvokable
    public final io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem backItem(){
        return backItem_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.webengine.widgets.QWebEngineHistoryItem backItem_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr/>backItems(int)const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem> backItems(int maxItems){
        return backItems_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), maxItems);
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.widgets.QWebEngineHistoryItem> backItems_native_int_constfct(long __this__nativeId, int maxItems);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr/>canGoBack()const</code></p>
     */
    @QtUninvokable
    public final boolean canGoBack(){
        return canGoBack_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean canGoBack_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr/>canGoForward()const</code></p>
     */
    @QtUninvokable
    public final boolean canGoForward(){
        return canGoForward_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean canGoForward_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr/>clear()</code></p>
     */
    @QtUninvokable
    public final void clear(){
        clear_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clear_native(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr/>count()const</code></p>
     */
    @QtUninvokable
    public final int count(){
        return count_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int count_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr/>currentItem()const</code></p>
     */
    @QtUninvokable
    public final io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem currentItem(){
        return currentItem_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.webengine.widgets.QWebEngineHistoryItem currentItem_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr/>currentItemIndex()const</code></p>
     */
    @QtUninvokable
    public final int currentItemIndex(){
        return currentItemIndex_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int currentItemIndex_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr/>forward()</code></p>
     */
    @QtUninvokable
    public final void forward(){
        forward_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void forward_native(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr/>forwardItem()const</code></p>
     */
    @QtUninvokable
    public final io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem forwardItem(){
        return forwardItem_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.webengine.widgets.QWebEngineHistoryItem forwardItem_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr/>forwardItems(int)const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem> forwardItems(int maxItems){
        return forwardItems_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), maxItems);
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.widgets.QWebEngineHistoryItem> forwardItems_native_int_constfct(long __this__nativeId, int maxItems);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr/>goToItem(QWebEngineHistoryItem)</code></p>
     */
    @QtUninvokable
    public final void goToItem(io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem item){
        goToItem_native_cref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(item));
    }
    
    @QtUninvokable
    private native void goToItem_native_cref_QWebEngineHistoryItem(long __this__nativeId, long item);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr/>itemAt(int)const</code></p>
     */
    @QtUninvokable
    public final io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem itemAt(int i){
        return itemAt_native_int_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), i);
    }
    
    @QtUninvokable
    private native io.qt.webengine.widgets.QWebEngineHistoryItem itemAt_native_int_constfct(long __this__nativeId, int i);
    
    /**
     * <p>See <code>QWebEngineHistory::<wbr/>items()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QList<io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem> items(){
        return items_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QList<io.qt.webengine.widgets.QWebEngineHistoryItem> items_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>operator&lt;&lt;(QDataStream&amp;,<wbr/>QWebEngineHistory)</code></p>
     */
    @QtUninvokable
    public void writeTo(io.qt.core.@StrictNonNull QDataStream stream){
        java.util.Objects.requireNonNull(stream, "Argument 'stream': null not expected.");
        writeTo_native_ref_QDataStream(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(stream));
    }
    
    @QtUninvokable
    private native void writeTo_native_ref_QDataStream(long __this__nativeId, long stream);
    
    /**
     * <p>See <code>operator&gt;&gt;(QDataStream&amp;,<wbr/>QWebEngineHistory&amp;)</code></p>
     */
    @QtUninvokable
    public void readFrom(io.qt.core.@StrictNonNull QDataStream stream){
        java.util.Objects.requireNonNull(stream, "Argument 'stream': null not expected.");
        readFrom_native_ref_QDataStream(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(stream));
    }
    
    @QtUninvokable
    private native void readFrom_native_ref_QDataStream(long __this__nativeId, long stream);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineHistory(QPrivateConstructor p) { super(p); } 
    
}
